function cm_responce_mat = build_cm_responce_mat_2D 
  % Builds a matrix that for the 2D problem holds the force-displacement 
  % curve in each collumn 
  % The number of first indices is the number of points in which the force 
  % displacement curve has been computed (in this case 9) 
  % The number of second and third indices is the number of points in which 
  % the axes have been sampled

  %..Set design parameter lower/upper bounds and step.. 
  pm_h_lb   = 5e-3;  %..lowest possible value for height coil consider..
  pm_h_ub   = 45e-3; 
  pm_h_step = (pm_h_ub - pm_h_lb) / 40;  
  pm_h_vec  = [pm_h_lb:pm_h_step:pm_h_ub];
  pm_w_lb   = 1e-3; 
  pm_w_ub   = 45e-3; 
  pm_w_step = (pm_w_ub - pm_w_lb) / 40;  
  pm_w_vec  = [pm_w_lb:pm_w_step:pm_w_ub];

  %..Initialize coarse model responce matrix..
  cm_responce_mat = zeros(9,length(pm_h_vec),length(pm_w_vec)); 

  for i=1:length(pm_h_vec) %..Fixed height.. 
    for j=1:length(pm_w_vec)

      %..Read an fd-curve from file..  
      filename = sprintf('../data/cm_data/fd_curve_%s_%s.dat', num2str(i),num2str(j));
      fd_curve = load(filename);
 
      cm_responce_mat(:,i,j) = fd_curve'; 

    end 
  end 


